==> lg-zoom-1.0.0.tgz: package/README.md <==
![travis](https://travis-ci.org/sachinchoolur/lg-zoom.js.svg?branch=master)
![bower](https://img.shields.io/bower/v/lg-zoom.js.svg)
![npm](https://img.shields.io/npm/v/lg-zoom.js.svg)

# Zoom module for [lightGallery](http://sachinchoolur.github.io/lightGallery/)
A customizable, modular, responsive, lightbox gallery plugin for jQuery.
![lightgallery](https://raw.githubusercontent.com/sachinchoolur/lightGallery/master/lib/lg.png)

Main features
---

* Zoom in and zoom out.
* Double click on images to see it's actual size.
* Zoom in/out the clicked position.
 
Browser support
---
lightgallery supports all major browsers including IE 9 and above..


Installation
---
#### Install with Bower

You can install lightgallery zoom plugin using the [Bower](http://bower.io) package manager.

```sh
$ bower install lg-zoom.js --save
```

#### npm

You can also find lightgallery zoom plugin on [npm](http://npmjs.org).

```sh
$ npm install lg-zoom.js
```
#### Download from Github

You can also directly download lg-zoom from github.

#### Include Javascript files
Include lg-zoom plugin after lightgallery.min.js.
``` html
<body>
   ---
    <!-- Include lightGallery -->
    <script src="js/lightgallery.min.js"></script>
    
    <!-- Include lg-zoom.js -->
    <script src="js/lg-zoom.min.js"></script>
    
    <!-- Include other lightgallery plugins (Optional) -->
    <script src="js/lg-thumbnail.min.js"></script>
</body>  
```

[Demos](http://sachinchoolur.github.io/lightGallery) 
----
  
[Docs](http://sachinchoolur.github.io/lightGallery/docs/api.html#lg-zoom)
-----

<!-- License
---

#### Commercial license
If you want to use lightGallery to develop commercial sites, themes, projects, and applications, the Commercial license is the appropriate license. With this option, your source code is kept proprietary. Purchase a lightGallery Commercial License at uplabs.com/posts/lightgallery

#### Open source license

If you are creating an open source application under a license compatible with the GNU GPL license v3, you may use this project under the terms of the GPLv3.
 -->

==> lg-zoom-1.0.1.tgz: package/README.md <==
![travis](https://travis-ci.org/sachinchoolur/lg-zoom.svg?branch=master)
![bower](https://img.shields.io/bower/v/lg-zoom.svg)
![npm](https://img.shields.io/npm/v/lg-zoom.svg)

# Zoom module for [lightGallery](http://sachinchoolur.github.io/lightGallery/)
A customizable, modular, responsive, lightbox gallery plugin for jQuery.
![lightgallery](https://raw.githubusercontent.com/sachinchoolur/lightGallery/master/lib/lg.png)

Main features
---

* Zoom in and zoom out.
* Double click on images to see it's actual size.
* Zoom in/out the clicked position.
 
Browser support
---
lightgallery supports all major browsers including IE 9 and above..


Installation
---
#### Install with Bower

You can install lightgallery zoom plugin using the [Bower](http://bower.io) package manager.

```sh
$ bower install lg-zoom --save
```

#### npm

You can also find lightgallery zoom plugin on [npm](http://npmjs.org).

```sh
$ npm install lg-zoom
```
#### Download from Github

You can also directly download lg-zoom from github.

#### Include Javascript files
Include lg-zoom plugin after lightgallery.min.js.
``` html
<body>
   ---
    <!-- Include lightGallery -->
    <script src="js/lightgallery.min.js"></script>
    
    <!-- Include lg-zoom -->
    <script src="js/lg-zoom.min.js"></script>
    
    <!-- Include other lightgallery plugins (Optional) -->
    <script src="js/lg-thumbnail.min.js"></script>
</body>  
```

[Demos](http://sachinchoolur.github.io/lightGallery) 
----
  
[Docs](http://sachinchoolur.github.io/lightGallery/docs/api.html#lg-zoom)
-----

License
---

#### Commercial license
If you want to use lightGallery to develop commercial sites, themes, projects, and applications, the Commercial license is the appropriate license. With this option, your source code is kept proprietary. Purchase a lightGallery Commercial License at [uplabs.com/posts/lightgallery-plugin](https://www.uplabs.com/posts/lightgallery-plugin)

#### Open source license

If you are creating an open source application under a license compatible with the GNU GPL license v3, you may use this project under the terms of the GPLv3.
